@@ -33,7 +33,8 @@ import Globals, log, TempFile, selection, robust, SetConnections, \
 
 class FSAbilities:
 	"""Store capabilities of given file system"""
-	extended_filenames = None # True if filenames can handle ":" etc.
+	extended_filenames = None # True if filenames can have non-ASCII chars
+	win_reserved_filenames = None # True if filenames can't have ",*,: etc.
 	case_sensitive = None # True if "foobar" and "FoObAr" are different files
 	ownership = None # True if chown works on this filesystem
 	acls = None # True if access control lists supported
@@ -91,7 +92,9 @@ class FSAbilities:
 							   self.dir_inc_perms),
 							  ('High-bit permissions', self.high_perms),
 							  ('Symlink permissions', self.symlink_perms),
-							  ('Extended filenames', self.extended_filenames)])
+							  ('Extended filenames', self.extended_filenames),
+							  ('Windows reserved filenames',
+							   self.win_reserved_filenames)])
 		add_boolean_list([('Access control lists', self.acls),
 						  ('Extended attributes', self.eas),
 						  ('Case sensitivity', self.case_sensitive),
@@ -141,6 +144,7 @@ class FSAbilities:
 		subdir.mkdir()
 
 		self.set_extended_filenames(subdir)
+		self.set_win_reserved_filenames(subdir)
 		self.set_case_sensitive_readwrite(subdir)
 		self.set_ownership(subdir)
 		self.set_hardlinks(subdir)
@@ -181,8 +185,9 @@ class FSAbilities:
 			if hl_source.getinode() != hl_dest.getinode():
 				raise IOError(errno.EOPNOTSUPP, "Hard links don't compare")
 		except (IOError, OSError):
-			log.Log("Warning: hard linking not supported by filesystem "
-					"at %s" % (self.root_rp.path,), 3)
+			if Globals.preserve_hardlinks != 0:
+				log.Log("Warning: hard linking not supported by filesystem "
+						"at %s" % (self.root_rp.path,), 3)
 			self.hardlinks = 0
 		else: self.hardlinks = 1
 
@@ -208,7 +213,7 @@ class FSAbilities:
 		ord_rp.delete()
 
 		# Try a UTF-8 encoded character
-		extended_filename = ':\\ ' + chr(225) + chr(132) + chr(137)
+		extended_filename = 'uni' + chr(225) + chr(132) + chr(137)
 		ext_rp = None
 		try:
 			ext_rp = subdir.append(extended_filename)
@@ -223,12 +228,35 @@ class FSAbilities:
 			except (IOError, OSError):
 				# Broken CIFS setups will sometimes create UTF-8 files
 				# and even stat them, but not let us perform file operations
-				# on them. Test file will be deleted via shutil.rmtree()
-				# when subdir is deleted. UTF-8 characters not in the
+				# on them. Test file cannot be deleted. UTF-8 chars not in the
 				# underlying codepage get translated to '?'
-				self.extended_filenames = 0
+				log.Log.FatalError("Could not delete extended filenames test "
+								   "file. If you are using a CIFS share, please"
+								   " see the FAQ entry about characters being "
+								   "transformed to a '?'")
+			self.extended_filenames = 1
+
+	def set_win_reserved_filenames(self, subdir):
+		"""Set self.win_reserved_filenames by trying to write a path"""
+		assert not self.read_only
+
+		# Try Windows reserved characters
+		win_reserved_filename = ':\\"'
+		win_rp = None
+		try:
+			win_rp = subdir.append(win_reserved_filename)
+			win_rp.touch()
+		except (IOError, OSError):
+			if win_rp: assert not win_rp.lstat()
+			self.win_reserved_filenames = 1
+		else:
+			assert win_rp.lstat()
+			try:
+				win_rp.delete()
+			except (IOError, OSError):
+				self.win_reserved_filenames = 1
 			else:
-				self.extended_filenames = 1
+				self.win_reserved_filenames = 0
 
 	def set_acls(self, rp):
 		"""Set self.acls based on rp.  Does not write.  Needs to be local"""
@@ -549,7 +577,7 @@ class BackupSetGlobals(SetGlobals):
 		log.Log("Backup: must_escape_dos_devices = %d" % \
 				(self.src_fsa.escape_dos_devices or local_edd), 4)
 
-	def set_chars_to_quote(self, rbdir):
+	def set_chars_to_quote(self, rbdir, force):
 		"""Set chars_to_quote setting for backup session
 
 		Unlike the other options, the chars_to_quote setting also
@@ -557,46 +585,61 @@ class BackupSetGlobals(SetGlobals):
 		directory, not just the current fs features.
 
 		"""
-		ctq = self.compare_ctq_file(rbdir, self.get_ctq_from_fsas())
+		(ctq, update) = self.compare_ctq_file(rbdir,
+				self.get_ctq_from_fsas(), force)
 
 		SetConnections.UpdateGlobal('chars_to_quote', ctq)
 		if Globals.chars_to_quote: FilenameMapping.set_init_quote_vals()
+		return update
 
 	def get_ctq_from_fsas(self):
 		"""Determine chars_to_quote just from filesystems, no ctq file"""
+		ctq = []
+
 		if self.src_fsa.case_sensitive and not self.dest_fsa.case_sensitive:
+			ctq.append("A-Z") # Quote upper case
+		if not self.dest_fsa.extended_filenames:
+			ctq.append('\000-\037') # Quote 0 - 31
+			ctq.append('\200-\377') # Quote non-ASCII characters 0x80 - 0xFF
+		if self.dest_fsa.win_reserved_filenames:
 			if self.dest_fsa.extended_filenames:
-				return "A-Z;" # Quote upper case and quoting char
-			# Quote the following 0 - 31, ", *, /, :, <, >, ?, \, |, ;
-			# Also quote uppercase A-Z
-			else: return 'A-Z\000-\037\"*/:<>?\\\\|\177;'
+				ctq.append('\000-\037') # Quote 0 - 31
+			# Quote ", *, /, :, <, >, ?, \, |, and 127 (DEL)
+			ctq.append('\"*/:<>?\\\\|\177')
 
-		if self.dest_fsa.extended_filenames:
-			return "" # Don't quote anything
-		else: return '\000-\037\"*/:<>?\\\\|\177;'
+		if ctq: ctq.append(';') # Quote quoting char if quoting anything
+		return "".join(ctq)
 
-	def compare_ctq_file(self, rbdir, suggested_ctq):
+	def compare_ctq_file(self, rbdir, suggested_ctq, force):
 		"""Compare ctq file with suggested result, return actual ctq"""
 		ctq_rp = rbdir.append("chars_to_quote")
 		if not ctq_rp.lstat():
 			if Globals.chars_to_quote is None: actual_ctq = suggested_ctq
 			else: actual_ctq = Globals.chars_to_quote
 			ctq_rp.write_string(actual_ctq)
-			return actual_ctq
+			return (actual_ctq, None)
 
 		if Globals.chars_to_quote is None: actual_ctq = ctq_rp.get_data()
 		else: actual_ctq = Globals.chars_to_quote # Globals override
 
-		if actual_ctq == suggested_ctq: return actual_ctq
+		if actual_ctq == suggested_ctq: return (actual_ctq, None)
 		if suggested_ctq == "":
 			log.Log("Warning: File system no longer needs quoting, "
 					"but we will retain for backwards compatibility.", 2)
-			return actual_ctq
+			return (actual_ctq, None)
 		if Globals.chars_to_quote is None:
-			log.Log.FatalError("""New quoting requirements!
+			if force:
+				log.Log("Warning: migrating rdiff-backup repository from"
+						"old quoting chars %r to new quoting chars %r" %
+						(actual_ctq, suggested_ctq), 2)
+				ctq_rp.delete()
+				ctq_rp.write_string(suggested_ctq)
+				return  (suggested_ctq, 1)
+			else:
+				log.Log.FatalError("""New quoting requirements!
 
-The quoting chars this session needs (%s) do not match
-the repository settings (%s) listed in
+The quoting chars this session needs %r do not match
+the repository settings %r listed in
 
 %s
 
@@ -604,7 +647,11 @@ This may be caused when you copy an rdiff-backup repository from a
 normal file system onto a windows one that cannot support the same
 characters, or if you backup a case-sensitive file system onto a
 case-insensitive one that previously only had case-insensitive ones
-backed up onto it.""" % (suggested_ctq, actual_ctq, ctq_rp.path))
+backed up onto it.
+
+By specificying the --force option, rdiff-backup will migrate the
+repository from the old quoting chars to the new ones.""" %
+			(suggested_ctq, actual_ctq, ctq_rp.path))
 
 
 class RestoreSetGlobals(SetGlobals):
@@ -686,7 +733,7 @@ class SingleSetGlobals(RestoreSetGlobals):
 			 ('carbonfile_active', 'carbonfile_write', 'carbonfile_conn'))
 
 
-def backup_set_globals(rpin):
+def backup_set_globals(rpin, force):
 	"""Given rps for source filesystem and repository, set fsa globals
 
 	This should be run on the destination connection, because we may
@@ -709,10 +756,14 @@ def backup_set_globals(rpin):
 	bsg.set_change_ownership()
 	bsg.set_high_perms()
 	bsg.set_symlink_perms()
-	bsg.set_chars_to_quote(Globals.rbdir)
+	update_quoting = bsg.set_chars_to_quote(Globals.rbdir, force)
 	bsg.set_escape_dos_devices()
 	bsg.set_must_escape_dos_devices(Globals.rbdir)
 
+	if update_quoting and force:
+		FilenameMapping.update_quoting(Globals.rbdir)
+
+
 def restore_set_globals(rpout):
 	"""Set fsa related globals for restore session, given in/out rps"""
 	assert rpout.conn is Globals.local_connection
