@@ -21,7 +21,7 @@
 
 from __future__ import generators
 import tempfile, os, cStringIO
-import static, rorpiter
+import static, rorpiter, FilenameMapping
 
 class RestoreError(Exception): pass
 
@@ -40,6 +40,7 @@ def Restore(mirror_rp, inc_rpath, target, restore_to_time):
 def get_inclist(inc_rpath):
 	"""Returns increments with given base"""
 	dirname, basename = inc_rpath.dirsplit()
+	if Globals.chars_to_quote: basename = FilenameMapping.unquote(basename)
 	parent_dir = inc_rpath.__class__(inc_rpath.conn, dirname, ())
 	if not parent_dir.isdir(): return [] # inc directory not created yet
 	index = inc_rpath.index
